Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1274)

Unified Diff: content/common/service_worker/service_worker_messages.h

Issue 1221643014: Service Worker: Migrate to version_uuid and surface ServiceWorker.id. (Chromium 2/3) (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/common/service_worker/service_worker_messages.h
diff --git a/content/common/service_worker/service_worker_messages.h b/content/common/service_worker/service_worker_messages.h
index a8ff04f6dd9b7853a0fa4b09b59160cffec45e8b..908ba887954649dc54849583efa20e2f736df96b 100644
--- a/content/common/service_worker/service_worker_messages.h
+++ b/content/common/service_worker/service_worker_messages.h
@@ -77,7 +77,7 @@ IPC_STRUCT_TRAITS_BEGIN(content::ServiceWorkerObjectInfo)
IPC_STRUCT_TRAITS_MEMBER(handle_id)
IPC_STRUCT_TRAITS_MEMBER(url)
IPC_STRUCT_TRAITS_MEMBER(state)
- IPC_STRUCT_TRAITS_MEMBER(version_id)
+ IPC_STRUCT_TRAITS_MEMBER(version_uuid)
IPC_STRUCT_TRAITS_END()
IPC_STRUCT_TRAITS_BEGIN(content::ServiceWorkerRegistrationObjectInfo)
@@ -192,10 +192,10 @@ IPC_MESSAGE_CONTROL1(ServiceWorkerHostMsg_TerminateWorker,
// Informs the browser that |provider_id| is associated
// with a service worker script running context and
// |version_id| identifies which ServiceWorkerVersion.
IPC_MESSAGE_CONTROL2(ServiceWorkerHostMsg_SetVersionId,
int /* provider_id */,
- int64 /* version_id */)
+ std::string /* version_uuid */)
// Informs the browser that event handling has finished.
// Routed to the target ServiceWorkerVersion.
« no previous file with comments | « content/common/service_worker/embedded_worker_messages.h ('k') | content/common/service_worker/service_worker_types.h » ('j') | no next file with comments »
@@ -192,10 +192,10 @@ IPC_MESSAGE_CONTROL1(ServiceWorkerHostMsg_TerminateWorker,
// Informs the browser that |provider_id| is associated
// with a service worker script running context and
-// |version_id| identifies which ServiceWorkerVersion.
+// |version_uuid| identifies which ServiceWorkerVersion.
IPC_MESSAGE_CONTROL2(ServiceWorkerHostMsg_SetVersionId,
int /* provider_id */,

Powered by Google App Engine
This is Rietveld 408576698